@@ -24,8 +24,8 @@ import logging
 import sys
 
 import gitlabracadabra
-import gitlabracadabra.manager
 import gitlabracadabra.parser
+from gitlabracadabra.gitlab.connections import GitlabConnections
 
 
 logger = logging.getLogger(__name__)
@@ -42,6 +42,10 @@ def _get_parser():
     parser.add_argument('-d', '--debug',
                         help='Debug mode (display HTTP requests)',
                         action='store_true')
+    parser.add_argument('--logging-format',
+                        help='Logging format',
+                        choices=['short', 'long'],
+                        default='short')
     parser.add_argument('-c', '--config-file', action='append',
                         help=('Configuration file to use. Can be used '
                               'multiple times.'))
@@ -58,8 +62,7 @@ def _get_parser():
                               'group, user, application_settings) as '
                               'Markdown.'))
     parser.add_argument('action_files',
-                        help='Action file. Can be used '
-                              'multiple times.',
+                        help='Action file. Can be used multiple times.',
                         metavar='ACTIONFILE.yml',
                         nargs='*',
                         default=['gitlabracadabra.yml'])
@@ -86,7 +89,11 @@ def main():
         log_level = logging.INFO
     if debug:
         log_level = logging.DEBUG
-    logging.basicConfig(format='%(asctime)s [%(process)d] %(levelname)-8.8s %(name)s: %(message)s', level=log_level)
+    if args.logging_format == 'long':
+        logging_format = '%(asctime)s [%(process)d] %(levelname)-8.8s %(name)s: %(message)s'
+    else:
+        logging_format = '%(levelname)-8.8s %(message)s'
+    logging.basicConfig(format=logging_format, level=log_level)
 
     if args.doc_markdown:
         cls = gitlabracadabra.parser.GitlabracadabraParser.get_class_for(args.doc_markdown)
@@ -94,8 +101,8 @@ def main():
         sys.exit(0)
 
     try:
-        gitlabracadabra.manager.preload(gitlab_id, config_files, debug)
-    except Exception as e:
+        GitlabConnections().load(gitlab_id, config_files, debug)
+    except Exception as e:  # noqa: B902
         logger.error(str(e))  # noqa: G200
         sys.exit(1)
 
@@ -113,8 +120,8 @@ def main():
         objects[action_file] = parser.objects()
         for k, v in sorted(objects[action_file].items()):
             if len(v.errors()) > 0:
-                for e in v.errors():
-                    logger.error('Error in %s::: %s', k, e.message)
+                for error in v.errors():
+                    logger.error('Error in %s (%s %s): %s', action_file, v._type_name(), k, str(error))
                 has_errors = True
 
     if has_errors:
@@ -128,4 +135,4 @@ def main():
 
 
 if __name__ == '__main__':
-    main()
+    main()  # type: ignore
