@@ -22,6 +22,7 @@ from typing import TYPE_CHECKING
 from urllib.request import parse_http_list, parse_keqv_list
 
 from requests import Response, Session, codes
+from requests.adapters import HTTPAdapter
 from requests.structures import CaseInsensitiveDict
 
 from gitlabracadabra.auth_info import AuthInfo
@@ -111,6 +112,8 @@ class RegistrySession(object):
         self._auth_info = auth_info or AuthInfo()
         self._scheme = 'https'
         self._session = Session()
+        self._session.mount('http://', HTTPAdapter(max_retries=3))
+        self._session.mount('https://', HTTPAdapter(max_retries=3))
         self._session.headers = CaseInsensitiveDict({'Docker-Distribution-Api-Version': 'registry/2.0'})
         # Tokens, by set of scopes (as query string or None for all scope)
         self._tokens: Dict[Optional[str], Token] = {}
