@@ -1,7 +1,6 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2020 Mathieu Parent <math.parent@gmail.com>
+# Copyright (C) 2019-2021 Mathieu Parent <math.parent@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -21,14 +20,15 @@ from copy import deepcopy
 
 from gitlab.exceptions import GitlabDeleteError
 
-from gitlabracadabra.objects.user import GitLabracadabraUser
-from gitlabracadabra.utils import access_level
+from gitlabracadabra.gitlab.access_levels import access_level
 
 
 logger = logging.getLogger(__name__)
 
 
 class MembersMixin(object):
+    """Object with members."""
+
     """_process_members()
 
     Process the members param.
@@ -41,18 +41,18 @@ class MembersMixin(object):
         current_members = dict([[member.username, member] for member in self._obj.members.list(all=True)])
         # We first check for already existing members
         for _member_username, member in sorted(current_members.items()):
-            GitLabracadabraUser.map_user(member.id, member.username)
+            self.connection.user_cache.map_user(member.id, member.username)
             if member.username in param_value.keys():
                 target_access_level = access_level(param_value[member.username])
                 if member.access_level != target_access_level:
                     if dry_run:
                         logger.info('[%s] NOT Changing user %s (%s) access level: %s -> %s (dry-run)',
-                                     self._name, member.username, member.name,
-                                     member.access_level, target_access_level)
+                                    self._name, member.username, member.name,
+                                    member.access_level, target_access_level)
                     else:
                         logger.info('[%s] Changing user %s (%s) access level: %s -> %s',
-                                     self._name, member.username, member.name,
-                                     member.access_level, target_access_level)
+                                    self._name, member.username, member.name,
+                                    member.access_level, target_access_level)
                         member.access_level = target_access_level
                         member.save()
                 param_value.pop(member.username)
@@ -60,10 +60,10 @@ class MembersMixin(object):
                 if unknown_members in ['delete', 'remove']:
                     if dry_run:
                         logger.info('[%s] NOT Removing member %s (%s) (dry-run)',
-                                     self._name, member.username, member.name)
+                                    self._name, member.username, member.name)
                     else:
                         logger.info('[%s] Removing member %s (%s)',
-                                     self._name, member.username, member.name)
+                                    self._name, member.username, member.name)
                         try:
                             member.delete()
                         except GitlabDeleteError as e:
@@ -71,21 +71,21 @@ class MembersMixin(object):
                                            self._name, member.username, member.name, e.error_message)
                 elif unknown_members not in ['ignore', 'skip']:
                     logger.warning('[%s] NOT Removing member: %s (%s)',
-                                    self._name, member.username, member.name)
+                                   self._name, member.username, member.name)
         # Remaining members
         for target_username, target_user_access in sorted(param_value.items()):
-            user_id = GitLabracadabraUser.get_id_from_username(target_username)
+            user_id = self.connection.user_cache.id_from_username(target_username)
             if user_id is None:
                 logger.warning('[%s] User not found %s',
-                                self._name, target_username)
+                               self._name, target_username)
                 continue
             target_access_level = access_level(target_user_access)
             if dry_run:
                 logger.info('[%s] NOT Adding user %s: %s -> %s (dry-run)',
-                             self._name, target_username, 0, target_access_level)
+                            self._name, target_username, 0, target_access_level)
             else:
                 logger.info('[%s] Adding user %s: %s -> %s',
-                             self._name, target_username, 0, target_access_level)
+                            self._name, target_username, 0, target_access_level)
                 self._obj.members.create({
                     'user_id': user_id,
                     'access_level': target_access_level,
