@@ -805,14 +805,21 @@ class GitLabracadabraApplicationSettings(GitLabracadabraObject):
         if param_name == 'first_day_of_week':
             if param_value == 'sunday':
                 return 0
-            elif param_value == 'monday':
+            if param_value == 'monday':
                 return 1
-            elif param_value == 'saturday':
+            if param_value == 'saturday':
                 return 6
-            else:
-                return param_value
-        else:
-            return GitLabracadabraObject._mangle_param(self, param_name, param_value)
+        # https://github.com/python-gitlab/python-gitlab/blob/8753add72061ea01c508a42d16a27388b1d92677/gitlab/v4/objects/settings.py#L80-L87
+        if param_name in [
+            'asset_proxy_allowlist',
+            'disabled_oauth_sign_in_sources',
+            'domain_allowlist',
+            'domain_denylist',
+            'import_sources',
+            'restricted_visibility_levels',
+        ]:
+            return ','.join([str(x) for x in param_value])
+        return GitLabracadabraObject._mangle_param(self, param_name, param_value)
 
     """"_unmangle_param()
 
@@ -822,11 +829,8 @@ class GitLabracadabraApplicationSettings(GitLabracadabraObject):
         if param_name == 'first_day_of_week':
             if param_value == 0:
                 return 'sunday'
-            elif param_value == 1:
+            if param_value == 1:
                 return 'monday'
-            elif param_value == 6:
+            if param_value == 6:
                 return 'saturday'
-            else:
-                return param_value
-        else:
-            return GitLabracadabraObject._unmangle_param(self, param_name, param_value)
+        return GitLabracadabraObject._unmangle_param(self, param_name, param_value)
