@@ -70,6 +70,7 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
         'packages_enabled',
         'wiki_access_level',
         'snippets_access_level',
+        'squash_option',
         'pages_access_level',
         'emails_disabled',
         # 'show_default_award_emojis',  # FIXME Gitlab
@@ -295,6 +296,11 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                 'description': 'Snippets access level.',
                 'enum': ['disabled', 'private', 'enabled'],
             },
+            'squash_option': {
+                'type': 'string',
+                'description': 'Squash option.',
+                'enum': ['never', 'always', 'default_on', 'default_off'],
+            },
             'pages_access_level': {
                 'type': 'string',
                 'description': 'Forking access level.',
@@ -1269,6 +1275,36 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                             },
                             'additionalProperties': False,
                         },
+                        {
+                            'type': 'object',
+                            'description': 'PyPI source',
+                            'properties': {
+                                'pypi': {
+                                    'type': 'object',
+                                    'properties': {
+                                        'index_url': {
+                                            'type': 'string',
+                                        },
+                                        'requirements': {
+                                            'oneOf': [
+                                                {
+                                                    'type': 'string',
+                                                },
+                                                {
+                                                    'type': 'array',
+                                                    'items': {
+                                                        'type': 'string',
+                                                    },
+                                                },
+                                            ],
+                                        },
+                                    },
+                                    'required': ['requirements'],
+                                    'additionalProperties': False,
+                                },
+                            },
+                            'additionalProperties': False,
+                        },
                     ],
                 },
                 '_example': ('\n'
