@@ -15,9 +15,15 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import logging
+from typing import Optional
+
 from gitlabracadabra.objects.object import GitLabracadabraObject
 
 
+logger = logging.getLogger(__name__)
+
+
 class GitLabracadabraUser(GitLabracadabraObject):
     EXAMPLE_YAML_HEADER = 'mmyuser:\n  type: user\n'
     DOC = [
@@ -34,6 +40,7 @@ class GitLabracadabraUser(GitLabracadabraObject):
         'skip_confirmation',
         'skip_reconfirmation',
         'public_email',
+        'state',
         '## Password',
         'password',
         'reset_password',
@@ -104,6 +111,18 @@ class GitLabracadabraUser(GitLabracadabraObject):
                 'type': 'string',
                 'description': 'The public email of the user',
             },
+            'state': {
+                'type': 'string',
+                'description': 'User state',
+                'enum': [
+                    'active',
+                    'banned',
+                    'blocked',
+                    'blocked_pending_approval',
+                    'deactivated',
+                    'ldap_blocked',
+                ],
+            },
             'password': {
                 'type': 'string',
                 'description': 'Password',
@@ -213,3 +232,59 @@ class GitLabracadabraUser(GitLabracadabraObject):
         if param_name == 'admin':
             param_name = 'is_admin'
         return super()._get_param(param_name)
+
+    """"_process_state()
+
+    Process the state param.
+    """
+    def _process_state(self, param_name, param_value, dry_run=False, skip_save=False):
+        assert param_name == 'state'  # noqa: S101
+        assert not skip_save  # noqa: S101
+
+        current_value = getattr(self._obj, param_name)
+        if current_value != param_value:
+            # From Gitlab's state machine
+            # https://gitlab.com/gitlab-org/gitlab/-/blob/8976bab138344e55e7feb1725cf63770d0a2741b/app/models/user.rb#L324-367
+            action = self._state_action(current_value, param_value)
+            if action is None:
+                logger.warning(
+                    '[%s] No action found to change param %s: %s -> %s (dry-run)',
+                    self._name,
+                    param_name,
+                    current_value,
+                    param_value,
+                )
+            elif dry_run:
+                logger.info(
+                    '[%s] NOT doing %s to change param %s: %s -> %s (dry-run)',
+                    self._name,
+                    action,
+                    param_name,
+                    current_value,
+                    param_value,
+                )
+            else:
+                logger.info(
+                    '[%s] Doing %s to change param %s: %s -> %s (dry-run)',
+                    self._name,
+                    action,
+                    param_name,
+                    current_value,
+                    param_value,
+                )
+                getattr(self._obj, action)()
+
+    """"_state_action()
+
+    Get action.
+    """
+    def _state_action(self, current: str, target: str) -> Optional[str]:
+        if target == 'active':
+            if current == 'blocked':
+                return 'unblock'
+            return 'activate'
+        if target == 'blocked':
+            return 'block'
+        if target == 'deactivated':
+            return 'deactivate'
+        return None
