@@ -64,7 +64,7 @@ class TestApplicationSettings(TestCaseWithManager):
             # 'external_authorization_service_enabled': True,  # FIXME Or the API will fail
             'external_authorization_service_timeout': 0.42,
             'external_authorization_service_url': 'https://authz.example.org/',
-            'first_day_of_week': 'sunday',
+            'first_day_of_week': 'monday',
             'gitaly_timeout_default': 110,
             'gitaly_timeout_fast': 20,
             'gitaly_timeout_medium': 60,
