@@ -16,30 +16,17 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from unittest import TestCase, skipIf
-try:
-    from unittest.mock import patch
-except ImportError:
-    from mock import patch  # Python 2
+from unittest import skipIf
 
-from gitlab import Gitlab, __version__ as gitlab_version
+from gitlab import __version__ as gitlab_version
 
-import gitlabracadabra.manager
 from gitlabracadabra.objects.project import GitLabracadabraProject
 from gitlabracadabra.objects.user import GitLabracadabraUser
-from gitlabracadabra.tests.utils import my_vcr
+from gitlabracadabra.tests import my_vcr, patch
+from gitlabracadabra.tests.case import TestCaseWithManager
 
 
-class TestProject(TestCase):
-    def setUp(self):
-        gitlabracadabra.manager._gitlab = Gitlab(  # noqa: S106
-            'http://localhost',
-            private_token='DKkdC5JmKWWZgXZGzg83',
-        )
-
-    def tearDown(self):
-        gitlabracadabra.manager._gitlab = None
-
+class TestProject(TestCaseWithManager):
     @my_vcr.use_cassette
     def test_no_create(self, cass):
         obj = GitLabracadabraProject('memory', 'test/no_create_object', {})
@@ -182,8 +169,8 @@ class TestProject(TestCase):
             obj.process()
             self.assertTrue(cass.all_played)
             logger.warning.assert_called_once_with('[%s] Group not found %s',
-                                                           'test/project_groups',
-                                                           'group_not_found')
+                                                   'test/project_groups',
+                                                   'group_not_found')
 
     @my_vcr.use_cassette
     def test_groups_delete_unknown(self, cass):
@@ -259,7 +246,7 @@ class TestProject(TestCase):
             obj.process()
             self.assertTrue(cass.all_played)
             logger.info.assert_called_once_with('[%s] Deleting unknown protected branch: %s',
-                                                   'test/protected_branches', 'master')
+                                                'test/protected_branches', 'master')
 
     @skipIf(gitlab_version in ['1.6.0'], 'python-gitlab without protected tags support')
     @my_vcr.use_cassette
@@ -299,7 +286,7 @@ class TestProject(TestCase):
             obj.process()
             self.assertTrue(cass.all_played)
             logger.info.assert_called_once_with('[%s] Deleting unknown protected tag: %s',
-                                                   'test/protected_tags', 'unknown')
+                                                'test/protected_tags', 'unknown')
 
     @my_vcr.use_cassette
     def test_archived(self, cass):
@@ -310,7 +297,7 @@ class TestProject(TestCase):
             obj.process()
             self.assertTrue(cass.all_played)
             logger.info.assert_called_once_with('[%s] Changing param %s: %s -> %s',
-                                                   'test/archived', 'archived', False, True)
+                                                'test/archived', 'archived', False, True)
 
     @my_vcr.use_cassette
     def test_unarchived(self, cass):
@@ -321,7 +308,7 @@ class TestProject(TestCase):
             obj.process()
             self.assertTrue(cass.all_played)
             logger.info.assert_called_once_with('[%s] Changing param %s: %s -> %s',
-                                                   'test/unarchived', 'archived', True, False)
+                                                'test/unarchived', 'archived', True, False)
 
     @my_vcr.use_cassette
     def test_variables(self, cass):
