@@ -87,3 +87,31 @@ class TestUser(TestCaseWithManager):
         self.assertEqual(obj.errors(), [])
         obj.process()
         self.assertTrue(cass.all_played)
+
+    @my_vcr.use_cassette
+    def test_block(self, cass):
+        # from active
+        obj = GitLabracadabraUser('memory', 'userfoo', {'state': 'blocked'})
+        obj.process()
+        self.assertTrue(cass.all_played)
+
+    @my_vcr.use_cassette
+    def test_unblock(self, cass):
+        # from blocked
+        obj = GitLabracadabraUser('memory', 'userfoo', {'state': 'active'})
+        obj.process()
+        self.assertTrue(cass.all_played)
+
+    @my_vcr.use_cassette
+    def test_deactivate(self, cass):
+        # from active
+        obj = GitLabracadabraUser('memory', 'userfoo', {'state': 'deactivated'})
+        obj.process()
+        self.assertTrue(cass.all_played)
+
+    @my_vcr.use_cassette
+    def test_activate(self, cass):
+        # from deactivated
+        obj = GitLabracadabraUser('memory', 'userfoo', {'state': 'active'})
+        obj.process()
+        self.assertTrue(cass.all_played)
